uim.model.helpers.policy API documentation

# Module `uim.model.helpers.policy`

Expand source code

    # -*- coding: utf-8 -*-
    # Copyright © 2021 Wacom Authors. All Rights Reserved.
    #
    #  Licensed under the Apache License, Version 2.0 (the "License");
    #  you may not use this file except in compliance with the License.
    #  You may obtain a copy of the License at
    #
    #      http://www.apache.org/licenses/LICENSE-2.0
    #
    #  Unless required by applicable law or agreed to in writing, software
    #  distributed under the License is distributed on an "AS IS" BASIS,
    #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    #  See the License for the specific language governing permissions and
    #  limitations under the License.
    from enum import Enum

    class HandleMissingDataPolicy(Enum):
        """
        Policy to handle missing data.
        """
        FILL_WITH_ZEROS = 1
        """Fill missing data with zeros"""
        SKIP_STROKE = 2
        """Skip the stroke"""
        THROW_EXCEPTION = 3
        """Raise an exception"""

## Classes

`class HandleMissingDataPolicy (value, names=None, *, module=None, qualname=None, type=None, start=1)`

  Policy to handle missing data.

  Expand source code

      class HandleMissingDataPolicy(Enum):
          """
          Policy to handle missing data.
          """
          FILL_WITH_ZEROS = 1
          """Fill missing data with zeros"""
          SKIP_STROKE = 2
          """Skip the stroke"""
          THROW_EXCEPTION = 3
          """Raise an exception"""

  ### Ancestors

  - enum.Enum

  ### Class variables

  `var FILL_WITH_ZEROS`

    Fill missing data with zeros

  `var SKIP_STROKE`

    Skip the stroke

  `var THROW_EXCEPTION`

    Raise an exception